@@ -1,4 +1,4 @@
-# Copyright 2012-2018 CERN for the benefit of the ATLAS collaboration.
+# Copyright 2012-2019 CERN for the benefit of the ATLAS collaboration.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,17 +14,17 @@
 #
 # Authors:
 # - Vincent Garonne <vgaronne@gmail.com>, 2012-2018
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2018
+# - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2019
 # - Angelos Molfetas <Angelos.Molfetas@cern.ch>, 2012
 # - Thomas Beermann <thomas.beermann@cern.ch>, 2012
 # - Joaquin Bogado <jbogado@linti.unlp.edu.ar>, 2014-2018
 # - Cheng-Hsi Chao <cheng-hsi.chao@cern.ch>, 2014
 # - Cedric Serfon <cedric.serfon@cern.ch>, 2015
-# - Martin Barisits <martin.barisits@cern.ch>, 2015-2016
+# - Martin Barisits <martin.barisits@cern.ch>, 2015-2019
 # - Frank Berghaus <frank.berghaus@cern.ch>, 2017-2018
 # - Tobias Wegner <twegner@cern.ch>, 2018
 # - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018-2019
-# - Andrew Lister, <andrew.lister@stfc.ac.uk>, 2019
+# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
 #
 # PY3K COMPATIBLE
 
@@ -41,8 +41,9 @@ from rucio.client.replicaclient import ReplicaClient
 from rucio.client.rseclient import RSEClient
 from rucio.client.ruleclient import RuleClient
 from rucio.common.config import config_get
-from rucio.common.types import InternalScope
+from rucio.common.types import InternalScope, InternalAccount
 from rucio.common.utils import generate_uuid, md5, render_json
+from rucio.daemons.abacus import account as abacus_account
 from rucio.tests.common import execute, account_name_generator, rse_name_generator, file_generator, scope_name_generator
 from rucio.rse import rsemanager as rsemgr
 
@@ -66,7 +67,7 @@ class TestBinRucio():
         self.replica_client = ReplicaClient()
         self.rule_client = RuleClient()
         self.account_client = AccountLimitClient()
-        self.account_client.set_account_limit('root', self.def_rse, -1)
+        self.account_client.set_local_account_limit('root', self.def_rse, -1)
 
         self.rse_client.add_rse_attribute(self.def_rse, 'istape', 'False')
 
@@ -76,7 +77,7 @@ class TestBinRucio():
         """CLIENT(USER): Rucio version"""
         cmd = 'bin/rucio --version'
         exitcode, out, err = execute(cmd)
-        nose.tools.assert_true('rucio' in err)
+        nose.tools.assert_true('rucio' in out or 'rucio' in err)
 
     def test_rucio_ping(self):
         """CLIENT(USER): Rucio ping"""
@@ -318,7 +319,7 @@ class TestBinRucio():
         print(out)
         print(err)
         # get the rule for the file
-        cmd = "rucio list-rules {0}:{1} | grep {0}:{1} | cut -f1 -d\ ".format(self.user, tmp_file1_name)
+        cmd = "rucio list-rules {0}:{1} | grep {0}:{1} | cut -f1 -d\ ".format(self.user, tmp_file1_name)  # NOQA: W605
         print(self.marker + cmd)
         exitcode, out, err = execute(cmd)
         print(out, err)
@@ -659,6 +660,7 @@ class TestBinRucio():
             metalink_file.write(replica_file)
         cmd = 'rucio download --dir /tmp --metalink {0}'.format(metalink_file_path)
         exitcode, out, err = execute(cmd)
+        remove(metalink_file_path)
         cmd = 'ls /tmp/{0}'.format(scope)
         exitcode, out, err = execute(cmd)
         nose.tools.assert_not_equal(re.search(tmp_file_name, out), None)
@@ -675,7 +677,7 @@ class TestBinRucio():
         rse_settings = rsemgr.get_rse_info(rse=self.def_rse)
         protocol = rsemgr.create_protocol(rse_settings, 'write')
         protocol.connect()
-        pfn = protocol.lfns2pfns(lfn).values()[0]
+        pfn = list(protocol.lfns2pfns(lfn).values())[0]
         protocol.put(filename[5:], pfn, filename[:5])
         protocol.close()
         remove(filename)
@@ -709,7 +711,7 @@ class TestBinRucio():
         rse_settings = rsemgr.get_rse_info(rse=self.def_rse)
         protocol = rsemgr.create_protocol(rse_settings, 'write')
         protocol.connect()
-        pfn = protocol.lfns2pfns(lfn).values()[0]
+        pfn = list(protocol.lfns2pfns(lfn).values())[0]
         protocol.put(filename[5:], pfn, filename[:5])
         protocol.close()
         remove(filename)
@@ -720,7 +722,7 @@ class TestBinRucio():
         exitcode, out, err = execute(cmd)
         print(out, err)
 
-        report = 'Local\ checksum\:\ {0},\ Rucio\ checksum\:\ 0123456789abcdef0123456789abcdef'.format(file_md5)
+        report = 'Local\ checksum\:\ {0},\ Rucio\ checksum\:\ 0123456789abcdef0123456789abcdef'.format(file_md5)  # NOQA: W605
         print('searching', report, 'in', err)
         nose.tools.assert_not_equal(re.search(report, err), None)
 
@@ -780,7 +782,7 @@ class TestBinRucio():
         exitcode, out, err = execute(cmd)
         print(out)
         # add quota
-        self.account_client.set_account_limit('root', tmp_rse, -1)
+        self.account_client.set_local_account_limit('root', tmp_rse, -1)
         # add rse atributes
         cmd = 'rucio-admin rse set-attribute --rse {0} --key spacetoken --value ATLASSCRATCHDISK'.format(tmp_rse)
         print(self.marker + cmd)
@@ -793,7 +795,7 @@ class TestBinRucio():
         exitcode, out, err = execute(cmd)
         print(out, err)
         # add quota
-        self.account_client.set_account_limit('root', tmp_rse, -1)
+        self.account_client.set_local_account_limit('root', tmp_rse, -1)
         # add rse atributes
         cmd = 'rucio-admin rse set-attribute --rse {0} --key spacetoken --value ATLASSCRATCHDISK'.format(tmp_rse)
         print(self.marker + cmd)
@@ -806,7 +808,7 @@ class TestBinRucio():
         exitcode, out, err = execute(cmd)
         print(out, err)
         # add quota
-        self.account_client.set_account_limit('root', tmp_rse, -1)
+        self.account_client.set_local_account_limit('root', tmp_rse, -1)
         # add rse atributes
         cmd = 'rucio-admin rse set-attribute --rse {0} --key spacetoken --value ATLASSCRATCHDISK'.format(tmp_rse)
         print(self.marker + cmd)
@@ -827,7 +829,7 @@ class TestBinRucio():
 
     def test_delete_rule(self):
         """CLIENT(USER): rule deletion"""
-        self.account_client.set_account_limit('root', self.def_rse, -1)
+        self.account_client.set_local_account_limit('root', self.def_rse, -1)
         tmp_file1 = file_generator()
         # add files
         cmd = 'rucio upload --rse {0} --scope {1} {2}'.format(self.def_rse, self.user, tmp_file1)
@@ -840,7 +842,7 @@ class TestBinRucio():
         print(self.marker + cmd)
         exitcode, out, err = execute(cmd)
         print(out)
-        self.account_client.set_account_limit('root', tmp_rse, -1)
+        self.account_client.set_local_account_limit('root', tmp_rse, -1)
 
         # add rse atributes
         cmd = 'rucio-admin rse set-attribute --rse {0} --key spacetoken --value ATLASSCRATCHDISK'.format(tmp_rse)
@@ -854,7 +856,7 @@ class TestBinRucio():
         print(err)
         print(out)
         # get the rules for the file
-        cmd = "rucio list-rules {0}:{1} | grep {0}:{1} | cut -f1 -d\ ".format(self.user, tmp_file1[5:])
+        cmd = "rucio list-rules {0}:{1} | grep {0}:{1} | cut -f1 -d\ ".format(self.user, tmp_file1[5:])  # NOQA: W605
         print(self.marker + cmd)
         exitcode, out, err = execute(cmd)
         print(out, err)
@@ -896,7 +898,7 @@ class TestBinRucio():
         exitcode, out, err = execute(cmd)
         print(out, err)
         # get the rule for the file
-        cmd = "rucio list-rules {0}:{1} | grep {0}:{1} | cut -f1 -d\ ".format(self.user, tmp_file1[5:])
+        cmd = "rucio list-rules {0}:{1} | grep {0}:{1} | cut -f1 -d\ ".format(self.user, tmp_file1[5:])  # NOQA: W605
         print(self.marker + cmd)
         exitcode, out, err = execute(cmd)
         print(out, err)
@@ -1223,3 +1225,59 @@ class TestBinRucio():
         cmd = 'rucio-admin replicas set-tombstone {0}:{1} --rse {2}'.format(scope, name, rse)
         exitcode, out, err = execute(cmd)
         nose.tools.assert_not_equal(re.search('Replica not found', err), None)
+
+    def test_list_account_limits(self):
+        """ CLIENT (USER): list account limits. """
+        rse = 'MOCK4'
+        rse_exp = 'MOCK3|MOCK4'
+        account = 'root'
+        local_limit = 10
+        global_limit = 20
+        self.account_client.set_local_account_limit(account, rse, local_limit)
+        self.account_client.set_global_account_limit(account, rse_exp, global_limit)
+        cmd = 'rucio list-account-limits {0}'.format(account)
+        exitcode, out, err = execute(cmd)
+        nose.tools.assert_not_equal(re.search('.*{0}.*{1}.*'.format(rse, local_limit), out), None)
+        nose.tools.assert_not_equal(re.search('.*{0}.*{1}.*'.format(rse_exp, global_limit), out), None)
+        cmd = 'rucio list-account-limits --rse {0} {1}'.format(rse, account)
+        exitcode, out, err = execute(cmd)
+        nose.tools.assert_not_equal(re.search('.*{0}.*{1}.*'.format(rse, local_limit), out), None)
+        nose.tools.assert_not_equal(re.search('.*{0}.*{1}.*'.format(rse_exp, global_limit), out), None)
+        self.account_client.set_local_account_limit(account, rse, -1)
+        self.account_client.set_global_account_limit(account, rse_exp, -1)
+
+    def test_list_account_usage(self):
+        """ CLIENT (USER): list account usage. """
+        if environ.get('SUITE', 'all') != 'client':
+            from rucio.db.sqla import session, models
+            from rucio.core.account_counter import increase
+            db_session = session.get_session()
+            db_session.query(models.AccountUsage).delete()
+            db_session.query(models.AccountLimit).delete()
+            db_session.query(models.AccountGlobalLimit).delete()
+            db_session.query(models.UpdatedAccountCounter).delete()
+            db_session.commit()
+            rse = 'MOCK4'
+            rse_id = self.rse_client.get_rse(rse)['id']
+            rse_exp = 'MOCK|MOCK4'
+            account = 'root'
+            usage = 4
+            local_limit = 10
+            local_left = local_limit - usage
+            global_limit = 20
+            global_left = global_limit - usage
+            self.account_client.set_local_account_limit(account, rse, local_limit)
+            self.account_client.set_global_account_limit(account, rse_exp, global_limit)
+            increase(rse_id, InternalAccount(account), 1, usage)
+            abacus_account.run(once=True)
+            cmd = 'rucio list-account-usage {0}'.format(account)
+            exitcode, out, err = execute(cmd)
+            print(out)
+
+            nose.tools.assert_not_equal(re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse, usage, local_limit, local_left), out), None)
+            nose.tools.assert_not_equal(re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse_exp, usage, global_limit, global_left), out), None)
+            cmd = 'rucio list-account-usage --rse {0} {1}'.format(rse, account)
+            nose.tools.assert_not_equal(re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse, usage, local_limit, local_left), out), None)
+            nose.tools.assert_not_equal(re.search('.*{0}.*{1}.*{2}.*{3}'.format(rse_exp, usage, global_limit, global_left), out), None)
+            self.account_client.set_local_account_limit(account, rse, -1)
+            self.account_client.set_global_account_limit(account, rse_exp, -1)
